@@ -12,7 +12,7 @@ gc()
 
 ### Concrete GenomicFeatures types
 .TxDb <-
-    setRefClass("TxDb", contains="AnnotationDb",
+    setRefClass("TxDb", contains=c("AnnotationDb", "OutOfMemoryObject"),
         fields=list(user2seqlevels0="integer",
                     user_seqlevels="character",
                     user_genome="character",
@@ -33,6 +33,23 @@ gc()
       }))
 
 
+### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+### saveRDS() method
+###
+
+setMethod("saveRDS", "TxDb",
+    function(object, file="", ascii=FALSE, version=NULL,
+             compress=TRUE, refhook=NULL)
+    {
+        stop(wmsg("TxDb objects contain out-of-memory data ",
+                  "so cannot be serialized reliably. Please use ",
+                  "saveDb() from the AnnotationDbi package instead. ",
+                  "Also see '?containsOutOfMemoryData' in the ",
+                  "BiocGenerics package for some context."))
+    }
+)
+
+
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### Low-level data loaders
 ###
