@@ -234,8 +234,7 @@ test_intronsByTranscript <- function()
 test_exonsBy_cdsBy_fiveUTRsByTranscript_threeUTRsByTranscript <- function()
 {
     ## ITAG4.1_gene_models.subset.gff: 10 coding transcripts
-    gff <- system.file("extdata", "GFF3_files",
-                       "ITAG4.1_gene_models.subset.gff",
+    gff <- system.file("extdata", "ITAG4.1_gene_models.subset.gff",
                        package="GenomicFeatures")
     txdb <- makeTxDbFromGFF(gff)
 
